#! /usr/bin/env python
# -*- coding: utf-8 -*-

import pygame
from vec2d import vec2d
import tileMap
import sprites
from collections import OrderedDict

class Level(object):
    def __init__(self, tileMap, objects, size):
        self.tileMap = tileMap
        self.objects = objects
        self.size = vec2d(size)
        self.stage = pygame.Surface(size)
    
    def update(self, game):
        for group in self.objects.itervalues():
            group.update(self, game)
    
    def draw(self, screen):
        self.stage.fill((100, 100, 100))
        
        self.tileMap.draw(self.stage)
        
        for group in self.objects.itervalues():
            group.draw(self.stage)
        
        offset = (- self.objects["player"].sprite.position * 2) + vec2d(300, 200)
        zStage = pygame.transform.scale(self.stage, self.size * 2)
        screen.blit(zStage, offset)



def load_level(name):
    if name == 0:
        tiles = tileMap.TileMap()
        tiles.load_from("l1", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((189, 81), 1))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((45, 45)))), 
                    ("enemies", pygame.sprite.Group()),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((90, 13), "text0.png"), sprites.Image((170, 104),\
                            "entertext.png")))
                    ])

    elif name == 1:
        tiles = tileMap.TileMap()
        tiles.load_from("l1", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((189, 81), 2))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((36, 83)))), 
                    ("enemies", pygame.sprite.Group()),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((90, 13), "text1.png")))
                    ])
    elif name == 2:
        tiles = tileMap.TileMap()
        tiles.load_from("l2", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((189, 81), 3))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((36, 83)))), 
                    ("enemies", pygame.sprite.Group()),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((90, 13), "text2.png")))
                    ])
    elif name == 3:
        tiles = tileMap.TileMap()
        tiles.load_from("l3", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((216, 198), 4), sprites.Exit((216, 45), 5))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((60, 60)))), 
                    ("enemies", pygame.sprite.Group()),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((150, 220), "text3.png")))
                    ])
    elif name == 4:
        tiles = tileMap.TileMap()
        tiles.load_from("l3", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((216, 198), 4), sprites.Exit((216, 45), 5))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((58, 129)))), 
                    ("enemies", pygame.sprite.Group(sprites.Enemy((200, 198), specialMutation=sprites.DoubleJumpMutation()))),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((150, 220), "text4.png"), sprites.Image((130, 13), "text5.png")))
                    ])
    elif name == 5:
        tiles = tileMap.TileMap()
        tiles.load_from("l5", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((243, 53), 6))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((63, 46)))), 
                    ("enemies", pygame.sprite.Group(sprites.CleverEnemy((200, 200), specialMutation=sprites.TripleJumpMutation(), 
                            attackMutation=sprites.SpikeMutation()))),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((35, 13), "text6.png")))
                    ])
    elif name == 6:
        tiles = tileMap.TileMap()
        tiles.load_from("l6", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((189, 126), 7))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((63, 46)))), 
                    ("enemies", pygame.sprite.Group(sprites.Enemy((180, 54), sprites.FasterMutation(), sprites.Mutation(), sprites.SpikeMutation()),
                                                    sprites.Enemy((70, 70), sprites.FasterMutation(), sprites.Mutation(), sprites.SpikeMutation()),
                                                    sprites.Enemy((80, 70), sprites.FasterMutation(), sprites.Mutation(), sprites.SpikeMutation()),
                                                    sprites.Enemy((90, 70), sprites.FasterMutation(), sprites.Mutation(), sprites.SpikeMutation()),
                                                    sprites.Enemy((100, 70), sprites.FasterMutation(), sprites.Mutation(), sprites.SpikeMutation()),)),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((30, 13), "text7.png")))
                    ])
    elif name == 7:
        tiles = tileMap.TileMap()
        tiles.load_from("l7", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((216, 72), 8))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((40, 70)))), 
                    ("enemies", pygame.sprite.Group( \
                                            sprites.CleverEnemy((120, 102), sprites.Mutation(), sprites.DoubleJumpMutation(), sprites.SpikeMutation()),
                                            sprites.CleverEnemy((130, 102), sprites.Mutation(), sprites.DoubleJumpMutation(), sprites.BombMutation()),
                                            sprites.CleverEnemy((160, 102), sprites.Mutation(), sprites.DoubleJumpMutation(), sprites.SpikeMutation()),
                                            sprites.CleverEnemy((190, 102), sprites.Mutation(), sprites.DoubleJumpMutation(), sprites.BombMutation()),
                                            sprites.CleverEnemy((210, 102), sprites.Mutation(), sprites.DoubleJumpMutation(), sprites.SpikeMutation()),
                                            sprites.CleverEnemy((220, 102), sprites.Mutation(), sprites.DoubleJumpMutation(), sprites.BombMutation()))),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0))))
                    ])
    elif name == 8:
        tiles = tileMap.TileMap()
        tiles.load_from("l7", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((216, 72), 9))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((56, 102)))), 
                    ("enemies", pygame.sprite.Group(sprites.CleverEnemy((220, 102), sprites.Mutation(),\
                            sprites.DoubleJumpMutation(), sprites.BombMutation()))),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0))))
                    ])
    elif name == 9:
        tiles = tileMap.TileMap()
        tiles.load_from("l9", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group(sprites.Exit((113, 162), 10))),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((56, 45)))), 
                    ("enemies", pygame.sprite.Group(sprites.Enemy((87, 120), sprites.FasterMutation()),
                                sprites.Enemy((96, 120), sprites.FasterMutation()), 
                                sprites.Enemy((105, 120), sprites.FasterMutation()), 
                                sprites.Enemy((114, 120), sprites.FasterMutation()), 
                                sprites.Enemy((123, 120), sprites.FasterMutation()), 
                                sprites.Enemy((132, 120), sprites.FasterMutation()), 
                                sprites.Enemy((141, 120), sprites.FasterMutation()),
                                sprites.CleverEnemy((50, 190), sprites.FasterMutation(), sprites.DoubleJumpMutation(), sprites.BombMutation()),
                                sprites.CleverEnemy((180, 190), sprites.FasterMutation(), sprites.DoubleJumpMutation(), sprites.BombMutation()),
                                )),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0))))
                    ])
    elif name == 10:
        tiles = tileMap.TileMap()
        tiles.load_from("l1", pygame.image.load("tileSheet.png").convert())
        objects = OrderedDict([ ("exits", pygame.sprite.Group()),
                    ("player", pygame.sprite.GroupSingle(sprites.Player((45, 45)))), 
                    ("enemies", pygame.sprite.Group()),
                    ("bullets", pygame.sprite.Group()),
                    ("bombs", pygame.sprite.Group()),
                    ("etc", pygame.sprite.Group(sprites.HUD(vec2d(0, 0)), sprites.Image((90, 13), "text8.png")))
                    ])
    
    return Level(tiles, objects, tiles.size*9)
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        